/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.condition.parameter
        .definitions.condition.parameter.definition;

import static com.google.common.collect.ImmutableMap.builder;

import java.util.List;
import java.util.Map;

import com.google.common.collect.ImmutableMap.Builder;

/**
 * The definition of parameter match patterns.
 */
public interface ParameterMatchPatterns {

    /**
     * Returns the parameter match pattern.
     *
     * @return the parameter match pattern
     */
    List<ParameterMatchPattern> getParameterMatchPattern();

    /**
     * The match pattern types of the parameter.
     */
    enum ParameterMatchPattern {
        /** The parameter is less than the other. */
        LESS_THAN(0),

        /** The parameter is not less than the other. */
        NOT_LESS_THAN(1),

        /** The parameter equals to the other. */
        EQUAL(2),

        /** The parameter does not equal to the other. */
        NOT_EQUAL(3),

        /** The parameter is greater than the other. */
        GREATER_THAN(4),

        /** The parameter is not greater than the other. */
        NOT_GREATER_THAN(5),

        /** The parameter is between two parameters. */
        BETWEEN(6),

        /** The parameter is periodical. */
        PERIODICAL(7);

        private static final Map<Integer, ParameterMatchPattern> VALUE_MAP;

        int value;

        ParameterMatchPattern(int value) {
            this.value = value;
        }

        /**
         * Returns the value of this parameter match pattern.
         *
         * @return the value
         */
        public int getIntValue() {
            return value;
        }

        static {
            Builder<Integer, ParameterMatchPattern> b = builder();
            for (ParameterMatchPattern enumItem :
                ParameterMatchPattern.values()) {
                b.put(enumItem.value, enumItem);
            }
            VALUE_MAP = b.build();
        }

        /**
         * Returns the parameter match pattern from the given value.
         *
         * @param value the given value
         * @return the parameter match pattern
         * @throws IllegalArgumentException if there is no mapping
         */
        public static ParameterMatchPattern forValue(int value) {
            ParameterMatchPattern pattern = VALUE_MAP.get(value);
            if (pattern == null) {
                throw new IllegalArgumentException();
            }
            return pattern;
        }
    }
}